@@ -11,7 +11,7 @@ output_dir = os.path.abspath(os.path.join(os.path.dirname(__file__), 'output'))
 class StartModule():
 
 	def __init__(self):
-		self._main_gui_func_ = ''
+		self._main_gui_func_ = 'hola'
 
 	def help(self):
 		Logger.printMessage(message=ht.getFunctionsNamesFromModule('ht_test'), debug_module=True)
